OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Forkert kodeord",
    "The new password can not be the same as the previous one" : "Det nye kodeord kan ikke være det samme som det forrige",
    "No user supplied" : "Intet brugernavn givet",
    "Authentication error" : "Adgangsfejl",
    "Wrong admin recovery password. Please check the password and try again." : "Forkert admin gendannelseskode. Se venligst koden efter og prøv igen.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend'en understøtter ikke skift af kodeord, men opdateringen af brugerens krypteringsnøgle blev gennemført.",
    "Unable to change password" : "Kunne ikke ændre kodeord",
    "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst systemadministratoren.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "installation og opdatering af apps via app-butikken eller sammensluttet Cloud deling",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL bruger en forældet %s version (%s). Husk at opdatere dit styresystem ellers vil funktioner såsom %s ikke fungere pålideligt.",
    "A problem occurred, please check your log files (Error: %s)" : "Der opstod en fejl - tjek venligst dine logfiler (fejl: %s)",
    "Migration Completed" : "Overflytning blev fuldført",
    "Group already exists." : "Gruppen findes allerede.",
    "Unable to add group." : "Kan ikke tilføje gruppen.",
    "Unable to delete group." : "Kan ikke slette gruppen.",
    "log-level out of allowed range" : "niveau for logregistrering går ud over tilladte interval",
    "Saved" : "Gemt",
    "test email settings" : "test e-mailindstillinger",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Der opstod et problem under afsendelse af e-mailen. Gennemse venligst dine indstillinger. (Fejl: %s)",
    "Email sent" : "E-mail afsendt",
    "You need to set your user email before being able to send test emails." : "Du skal angive din bruger-e-mail før der kan sendes test-e-mail.",
    "Invalid mail address" : "Ugyldig mailadresse",
    "A user with that name already exists." : "Dette brugernavn eksistere allerede.",
    "Unable to create user." : "Kan ikke oprette brugeren.",
    "Your %s account was created" : "Din %s-konto blev oprettet",
    "Unable to delete user." : "Kan ikke slette brugeren.",
    "Forbidden" : "Forbudt",
    "Invalid user" : "Ugyldig bruger",
    "Unable to change mail address" : "Kan ikke ændre mailadresse",
    "Your full name has been changed." : "Dit fulde navn er blevet ændret.",
    "Unable to change full name" : "Ikke i stand til at ændre dit fulde navn",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Dansk",
    "Language changed" : "Sprog ændret",
    "Invalid request" : "Ugyldig forespørgsel",
    "Admins can't remove themself from the admin group" : "Administratorer kan ikke fjerne dem selv fra admin gruppen",
    "Unknown user" : "Ukendt bruger",
    "Couldn't remove app." : "Kunne ikke fjerne app'en.",
    "Official" : "Officiel",
    "Approved" : "Godkendt",
    "All" : "Alle",
    "Enabled" : "Aktiveret",
    "Not enabled" : "Slået fra",
    "No apps found for your version" : "Ingen apps fundet til din verion",
    "The app will be downloaded from the app store" : "Appen bliver downloadet fra appstoren",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Officielt program er udviklet af ownCloud fællesskabet. Funktionerne spiller en central rolle i ownCloud og kan bruges i produktionsmiljøer.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Godkendte programmer er udviklet af betroet udviklere som har bestået en let sikkerheds gennemgang. De er aktivt vedligeholdt i et åben kode lager og udviklerne vurdere programmet til at være stabilt for normalt brug.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Dette program er ikke kontrolleret for sikkerhedsproblemer, og er nyt eller kendt for at være ustabilt. Installer på eget ansvar.",
    "Please wait...." : "Vent venligst...",
    "Error while disabling app" : "Kunne ikke deaktivere app",
    "Disable" : "Deaktiver",
    "Enable" : "Aktiver",
    "Error while enabling app" : "Kunne ikke aktivere app",
    "Error: this app cannot be enabled because it makes the server unstable" : "Fejl: denne app kan ikke aktiveres fordi den gør serveren ustabil",
    "Error: could not disable broken app" : "Fejl: kunne ikke deaktivere fejlet app",
    "Error while disabling broken app" : "Fejl opstod mens fejlet app blev deaktiveret",
    "Updating...." : "Opdaterer....",
    "Error while updating app" : "Der opstod en fejl under app opgraderingen",
    "Updated" : "Opdateret",
    "Uninstalling ...." : "Afinstallerer...",
    "Error while uninstalling app" : "Fejl under afinstallering af app",
    "Uninstall" : "Afinstallér",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er blevet aktiveret, men skal opdateres. Du bliver videresendt til opdateringssiden om 5 sekunder.",
    "App update" : "Appopdatering",
    "Experimental" : "Eksperimentel",
    "No apps found for {query}" : "Ingen app fundet for {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sikker på at du vil tilføje \"{domain}\" som et domæne du har tiilid til?",
    "Add trusted domain" : "Tilføj et domæne som du har tillid til",
    "Migration in progress. Please wait until the migration is finished" : "Immigration er i gang. Vent venligst indtil overflytningen er afsluttet",
    "Migration started …" : "Migrering er påbegyndt...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Der opstod en fejl. Upload venligst et ASCII-indkodet PEM-certifikat.",
    "Valid until {date}" : "Gyldig indtil {date}",
    "Delete" : "Slet",
    "Disconnect" : "Koble fra",
    "Error while loading browser sessions and device tokens" : "Fejl ved indlæsning browsersessioner og enhedens mærkater",
    "Error while creating device token" : "Fejl ved oprettelse af en enhedsmærkat",
    "Error while deleting the token" : "Fejl under sletning af mærkat",
    "Sending..." : "Sender...",
    "An error occurred: {message}" : "Der opstod en fejl:{message}",
    "Select a profile picture" : "Vælg et profilbillede",
    "Very weak password" : "Meget svagt kodeord",
    "Weak password" : "Svagt kodeord",
    "So-so password" : "Jævnt kodeord",
    "Good password" : "Godt kodeord",
    "Strong password" : "Stærkt kodeord",
    "Groups" : "Grupper",
    "Unable to delete {objName}" : "Kunne ikke slette {objName}",
    "Error creating group: {message}" : "Fejl ved oprettelse af gruppe: {message}",
    "A valid group name must be provided" : "Et gyldigt gruppenavn skal angives ",
    "deleted {groupName}" : "slettede {groupName}",
    "undo" : "fortryd",
    "never" : "aldrig",
    "deleted {userName}" : "slettede {userName}",
    "add group" : "Tilføj gruppe",
    "Invalid quota value \"{val}\"" : "Ugyldig kvote værdi \"{val}\"",
    "enabled" : "aktiveret",
    "disabled" : "deaktiveret",
    "no group" : "ingen gruppe",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Ændring af kodeordet vil føre til datatab, fordi datagendannelse ikke er tilgængelig for denne bruger",
    "Password successfully changed" : "Adgangskoden er ændret med succes",
    "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
    "Error creating user: {message}" : "Fejl under oprettelse af bruger: {message}",
    "A valid password must be provided" : "En gyldig adgangskode skal angives",
    "A valid email must be provided" : "Der skal angives en gyldig e-mail",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hejsa,<br><br>dette er blot en besked om, at du nu har en %s-konto.<br><br>Dit brugernavn: %s<br>Tilgå den: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Hej!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hejsa,\n\ndette er blot en besked om, at du nu har en %s-konto.\n\nDit brugernavn: %s\nTilgå den: %s\n\n",
    "User documentation" : "Brugerdokumentation",
    "Administrator documentation" : "Administratordokumentation",
    "Online documentation" : "Online dokumentation",
    "Forum" : "Forum",
    "Issue tracker" : "Problem følger",
    "Commercial support" : "Kommerciel support",
    "Developer documentation" : "Dokumentation for udviklere",
    "by %s" : "af %s",
    "%s-licensed" : "%s-licenseret",
    "Documentation:" : "Dokumentation:",
    "Admin documentation" : "Admin-dokumentation",
    "Visit website" : "Besøg hjemmeside",
    "Report a bug" : "Rapporter en fejl",
    "Show description …" : "Vis beskrivelse",
    "Hide description …" : "Skjul beskrivelse",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Denne app har ikke fået tildelt en minimal ownCloud-version. Dette vil give en fejlmeddelelse i ownCloud 11 og nyere.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Denne app har ikke fået tildelt en maximal ownCloud-version. Dette vil give en fejlmeddelelse i ownCloud 11 og nyere.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Dette program kan ikke installeres, da følgende afhængigheder ikke imødekommes:",
    "Enable only for specific groups" : "Aktivér kun for udvalgte grupper",
    "Uninstall App" : "Afinstallér app",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Seneste udførsel af cronjob: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Seneste udførsel af cronjob: %s. Der er vist noget galt.",
    "Cron was not executed yet!" : "Cron har ikke kørt endnu!",
    "Open documentation" : "Åben dokumentation",
    "Execute one task with each page loaded" : "Udføre en opgave med hver side indlæsning",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php er registreret til at en webcron service skal kalde cron.php hvert 15 minut over http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Brug systemets cron service til at kalde cron.php hver 15. minut",
    "SSL Root Certificates" : "SSL rodcertifikater",
    "Common Name" : "Almindeligt navn",
    "Valid until" : "Gyldig indtil",
    "Issued By" : "Udstedt af",
    "Valid until %s" : "Gyldig indtil %s",
    "Import root certificate" : "Importer rodcertifikat",
    "Server-side encryption" : "Kryptering på serversiden",
    "Enable server-side encryption" : "Slå kryptering til på serversiden",
    "Please read carefully before activating server-side encryption: " : "Læs venligst dette omhyggeligt, før der aktivere kryptering på serversiden:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Når først kryptering er aktiveret, vil alle filer lagt ind på serveren, fra det tidspunkt krypteres og ligge på serveren. Det vil kun være muligt at deaktivere kryptering på en senere dato, hvis det aktive krypteringsmodul understøtter denne funktion, og alle forudsætninger er opfyldt (f.eks. sætte en gendannelsesnøgle).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Kryptering alene garanterer ikke for systemets sikkerhed. Se venligst ownCloud dokumentationen for mere information om, hvordan krypterings app fungerer, samt de understøttede brugseksempler.",
    "Be aware that encryption always increases the file size." : "Vær opmærksom på at kryptering altid øger filstørrelsen.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det er altid godt, at oprette regelmæssige sikkerhedskopieringer af dine data, og når der krypteres, sørge for at sikkerhedskopiere og håndtere krypteringsnøglerne lige så sikkert som dine data.",
    "This is the final warning: Do you really want to enable encryption?" : "Dette er den sidste advarsel: Sikker på at du vil slå kryptering til?",
    "Enable encryption" : "Slå kryptering til",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Der er ikke indlæst et krypteringsmodul - slå venligst et krypteringsmodul til i app-menuen.",
    "Select default encryption module:" : "Vælg standardmodulet til kryptering:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du skal immigrere dine krypteringsnøgler fra den gamle kryptering (ownCloud <= 8.0) til den nye af slagsen. Slå venligst \"Standardmodul til kryptering\" til, og kør \"occ encryption:migrate\"",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du skal immigrere dine krypteringsnøgler fra den gamle kryptering (ownCloud <= 8.0) til den nye af slagsen.",
    "Start migration" : "Påbegynd immigrering",
    "Sharing" : "Deling",
    "Allow apps to use the Share API" : "Tillad apps til at bruge Share API",
    "Allow users to share via link" : "Tillad brugere at dele via link",
    "Allow public uploads" : "Tillad offentlig upload",
    "Enforce password protection" : "Tving kodeords beskyttelse",
    "Set default expiration date" : "Vælg standard udløbsdato",
    "Allow users to send mail notification for shared files" : "Tillad brugere at sende mail underretninger for delte filer",
    "Allow users to share file via social media" : "Tillad brugere at dele via socialt media",
    "Expire after " : "Udløber efter",
    "days" : "dage",
    "Enforce expiration date" : "Påtving udløbsdato",
    "Allow resharing" : "Tillad videredeling",
    "Allow sharing with groups" : "Tillad deling med grupper",
    "Restrict users to only share with users in their groups" : "Begræns brugere til kun at dele med brugere i deres egen gruppe",
    "Allow users to send mail notification for shared files to other users" : "Tillader brugere at sende mailnotifikationer for delte filer til andre brugere",
    "Exclude groups from sharing" : "Ekskluder grupper fra at dele",
    "These groups will still be able to receive shares, but not to initiate them." : "Disse grupper vil stadig kunne modtage delefiler, men ikke skabe dem.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Tillad autofuldførelse af brugernavnet i delings dialogboksen. Hvis funktion er deaktiveret skal det fulde brugernavn indtastes.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Alt (alvorlige fejl, fejl, advarsler, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, advarsler, fejl og alvorlige fejl",
    "Warnings, errors and fatal issues" : "Advarsler, fejl og alvorlige fejl",
    "Errors and fatal issues" : "Fejl og alvorlige fejl",
    "Fatal issues only" : "Kun alvorlige fejl",
    "Log" : "Log",
    "What to log" : "Hvad skal logges",
    "Download logfile (%s)" : "Hent logfil (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Logfilen er større end 100 MB. Det kan tage en del tid at hente den!",
    "None" : "Ingen",
    "Login" : "Login",
    "Plain" : "Klartekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-mailserver",
    "This is used for sending out notifications." : "Dette anvendes til udsendelse af notifikationer.",
    "Send mode" : "Tilstand for afsendelse",
    "Encryption" : "Kryptering",
    "From address" : "Fra adresse",
    "mail" : "mail",
    "Authentication method" : "Godkendelsesmetode",
    "Authentication required" : "Godkendelse påkrævet",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Credentials" : "Brugeroplysninger",
    "SMTP Username" : "SMTP Brugernavn",
    "SMTP Password" : "SMTP Kodeord",
    "Store credentials" : "Gem brugeroplysninger",
    "Test email settings" : "Test e-mail-indstillinger",
    "Send email" : "Send e-mail",
    "Security & setup warnings" : "Advarsler om sikkerhed og opsætning",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "php lader ikke til at være korrekt opsat til at forespørge miljøvariablerne i systemet. Testen med getenv(\"PATH\") returnerer blot et tomt svar.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Tjek venligst <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installationsdokumentationen ↗</a> for php konfigurations-noter og php konfigurationen af din server, især ved brug af php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Den skrivebeskyttede konfiguration er blevet slået til. Dette forhindrer indstillinger af nogle konfigurationer via webgrænsefladen. I tillæg skal filen gøres skrivbar manuelt for hver opdatering.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP opsætning blokere \"inline doc blocks\". dette gør at flere grundlæggende apps utilgængelige",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Din database kører ikke med \"LÆS OPMÆRKSOMT\" transaktion-isolations-niveau. Dette kan give problemer, når flere handlinger udføres parallelt.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s under version %2$s er installeret, for stabilitets- og ydelsesmæssige årsager anbefaler vi opdatere til en nyere %1$s version.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP modulet 'fileinfo' mangler. Vi anbefaler stærkt at aktivere dette modul til at få de bedste resultater med mime-type detektion.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transaktions-fillåsning er deaktiveret, dette kan føre til problemer med hastighedsniveauet. Aktivér 'filelocking.enabled' i config.php for at undgå disse problemer. Se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentationen ↗</a> for mere information.",
    "System locale can not be set to a one which supports UTF-8." : "Systemets lokalitet kan ikke sættes til et der bruger UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Det betyder at der kan være problemer med visse tegn i filnavne.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Vi anbefaler kraftigt, at du installerer den krævede pakke på dit system, for at understøtte følgende lokaliteter: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Hvis din installation ikke er installeret i roden af domænet, og bruger systemets cron, så kan der være problemer med URL-oprettelsen. For at undgå disse problemer, så angiv tilvalget \"overwrite.cli.url\" i din fil config.php til webrodens sti for din installation (foreslået værdi: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite bruges som database. Til større installationer anbefaler vi at skifte til en anden database-backend.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Brug af SQLite frarådes især når skrivebordsklienten anvendes til filsynkronisering.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "For at migrere til en anden database brug kommandolinjeværktøjet: 'occ db:convert-type', eller se <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentationen ↗</a>.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Det var ikke muligt at udføre cronjobbet via kommandolinjefladen CLI. Følgende tekniske fejl fremkom:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Dobbelttjek <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installationsvejledningerne ↗ </a>, og tjek for eventuelle fejl eller advarsler i <a href=\"#log-section\">log</a>.",
    "All checks passed." : "Alle tjek blev bestået.",
    "Tips & tricks" : "Tips & tricks",
    "How to do backups" : "Hvordan man laver sikkerhedskopier",
    "Advanced monitoring" : "Avancerede monitorering",
    "Performance tuning" : "Ydelses optimering",
    "Improving the config.php" : "Forbedring af config.php",
    "Theming" : "Temaer",
    "Hardening and security guidance" : "Modstanddygtighed og sikkerheds vejledning",
    "Get the apps to sync your files" : "Hent applikationerne for at synkronisere dine filer",
    "Desktop client" : "Skrivebordsklient",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "Show First Run Wizard again" : "Vis guiden for første kørsel igen.",
    "Profile picture" : "Profilbillede",
    "Upload new" : "Upload nyt",
    "Select from Files" : "Vælg fra Filer",
    "Remove image" : "Fjern billede",
    "png or jpg, max. 20 MB" : "png eller jpg, max. 20 MB",
    "Picture provided by original account" : "Billede kommer fra oprindelig konto",
    "Cancel" : "Annuller",
    "Choose as profile picture" : "Vælg et profilbillede",
    "Full name" : "Fulde navn",
    "No display name set" : "Der er ikke angivet skærmnavn",
    "Email" : "E-mail",
    "Your email address" : "Din e-mailadresse",
    "For password recovery and notifications" : "Angiv en e-mailadresse for at aktivere gendannelse af adgangskode og modtage notifikationer",
    "No email address set" : "Der er ikke angivet e-mailadresse",
    "You are member of the following groups:" : "Der er medlem af følgende grupper:",
    "Password" : "Kodeord",
    "Unable to change your password" : "Ude af stand til at ændre dit kodeord",
    "Current password" : "Nuværende adgangskode",
    "New password" : "Nyt kodeord",
    "Change password" : "Skift kodeord",
    "Language" : "Sprog",
    "Help translate" : "Hjælp med oversættelsen",
    "Unlimited" : "Ubegrænset",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Udviklet af {communityopen}ownCloud-fællesskabet{linkclose}, {githubopen}kildekoden{linkclose} er udgivet under licensen {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Visitter",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Disse er netbaserede, stationære og mobile gæster logget ind på din ownCloud.",
    "Browser" : "Browser",
    "Most recent activity" : "Seneste aktivitet",
    "App passwords" : "Appkodeord",
    "You've linked these apps." : "Du har linket disse apps.",
    "Name" : "Navn",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Et app-kodeord er en adgangskode, der giver en app eller enhed tilladelse til at få adgang til din %s konto.",
    "App name" : "App navn",
    "Create new app password" : "Opret ny app adgangskode",
    "Use the credentials below to configure your app or device." : "Brug legitimationsoplysningerne nedenfor for at konfigurere din app eller enhed.",
    "Username" : "Brugernavn",
    "Done" : "Færdig",
    "Version" : "Version",
    "Personal" : "Personligt",
    "Admin" : "Admin",
    "Error" : "Fejl",
    "Show storage location" : "Vis placering af lageret",
    "Show last log in" : "Vis seneste login",
    "Show user backend" : "Vis bruger-backend",
    "Send email to new user" : "Send e-mail til ny bruger",
    "Show email address" : "Vis e-mailadresse",
    "E-Mail" : "E-mail",
    "Create" : "Ny",
    "Admin Recovery Password" : "Administrator gendannelse kodeord",
    "Enter the recovery password in order to recover the users files during password change" : "Indtast et gendannelse kodeord for, at kunne gendanne brugerens filer ved ændring af kodeord",
    "Add Group" : "Tilføj Gruppe",
    "Group" : "Gruppe",
    "Everyone" : "Alle",
    "Admins" : "Administratore",
    "Default Quota" : "Standard kvote",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Indtast venligst lagerkvote (f.eks. \"512 MB\" eller \"12 GB\")",
    "Other" : "Andet",
    "Full Name" : "Fulde navn",
    "Group Admin for" : "Gruppeadministrator for",
    "Quota" : "Kvote",
    "Storage Location" : "Placering af lageret",
    "User Backend" : "Bruger-backend",
    "Last Login" : "Seneste login",
    "change full name" : "ændre fulde navn",
    "set new password" : "skift kodeord",
    "change email address" : "skift e-mailadresse",
    "Default" : "Standard",
    "Change email" : "Skift email",
    "Share" : "Del",
    "installing and updating apps via the market or Federated Cloud Sharing" : "installation og opdatering af apps via app-butikken eller Federated Cloud Cloud deling",
    "System Status" : "Systemstatus",
    "Domain" : "Domæne",
    "Add" : "Tilføj",
    "Set email" : "Indstil email",
    "You are using %s of %s" : "Du bruger %s af %s",
    "Apps Management" : "Apphåndtering",
    "Show enabled apps" : "Vis aktiverede apps",
    "Show disabled apps" : "Vis deaktiverede aps",
    "Restrict enumeration to group members" : "Begræns nummereringen til gruppemedlemmer",
    "You are using %s of %s (%s %%)" : "Du bruger %s af %s (%s %%)",
    "%s password changed successfully" : "App %s succesfuldt opdateret",
    "No panels for this section." : "Intet panel for denne sektion.",
    "Failed to change the email address." : "Fejlede i at ændre emailadressen.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Vi anbefaler at aktivere stystem-cron eftersom andre cron-metoder muligvis kan påvirke performance og pålidelighed.",
    "Email has been changed successfully." : "Email er succesfuldt blevet opdateret."
},
"nplurals=2; plural=(n != 1);");
